from mastercardapicore import *

# import apis resourceconfig
from mastercardp2p.resourceconfig import ResourceConfig


# import apis into api package
from mastercardp2p.accountinfo import *
from mastercardp2p.accountverification import *
from mastercardp2p.consumer import *
from mastercardp2p.consumeraccount import *
from mastercardp2p.consumercontactid import *
from mastercardp2p.consumergovernmentid import *
from mastercardp2p.paymenttransfer import *
from mastercardp2p.sanctionscreening import *
